%%%% 3DLDFtex.base

%% * Copyright and License.@>

%%% This file is part of 3DLDF, a package for three-dimensional drawing. 
%%% Copyright (C) 2003, 2004 Laurence D. Finston. 

%%% 3DLDF is free software; you can redistribute it and/or modify 
%%% it under the terms of the GNU General Public License as published by 
%%% the Free Software Foundation; either version 2 of the License, or 
%%% (at your option) any later version. 

%%% 3DLDF is distributed in the hope that it will be useful, 
%%% but WITHOUT ANY WARRANTY; without even the implied warranty of 
%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
%%% GNU General Public License for more details. 

%%% You should have received a copy of the GNU General Public License 
%%% along with 3DLDF; if not, write to the Free Software 
%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 

%%% The author can be contacted at: 

%%% Laurence D. Finston 
%%% Kreuzbergring 41 
%%% D-37075 Goettingen 
%%% Germany 

%%% lfinsto1@gwdg.de 
%%% s246794@stud.uni-goettingen.de 


%%%%	$Id: 3DLDFtex.bas,v 1.3 2004/01/12 21:26:37 lfinsto1 Exp $	

\newif\ifxlrg
\newif\ifavier
\newif\ifadrei
\newif\iflandscape

\newif\iftesting


%% Local Variables:
%% mode:TeX
%% End:
